# Function for computing Mean Annual Air Temperature (MAAT) index
#
# Seasonal thawing–freezing n factor (nt∕nf)
# The seasonal thawing–freezing n factor (nt∕nf) relates thawing and 
# freezing degree-days (DDTa∕DDTs∕DDFa∕DDFs) 
# in seasonal air temperature to ground surface temperatures; 
# 
# nt = DDTs/DDTa
# nf = DDFs/DDFa
# where DDTa = ∑Ta, Ta > 0
#       DDFa = ∑Ta, Ta < 0
#		DDTs = ∑Ts, Ts > 0
#		DDFs = ∑Ts, Ts < 0
# MAAT = (DDTa−DDFa)/P, P=365
#
# Reference:
# Riseborough, D., Shiklomanov, N., Etzelmuller, B., Gruber, S., and Marchenko, S.: 
#   Recent advances in permafrost modelling, Permafrost Periglac., 19, 137–156, 2008.
#   http://doi.org/10.1002/ppp.615
#
# Luo, L., Zhang, Z., Ma, W., Yi, S., and Zhuang, Y.: PIC v1.3: 
#   comprehensive R package for computing permafrost indices with daily weather observations 
#   and atmospheric forcing over the Qinghai–Tibet Plateau, Geosci Model Dev, 11, 2475-2491, 2018. 
#   https://doi.org/10.5194/gmd-11-2475-2018
# 
# Author: Lihui Luo (E-mail: luolh@lzb.ac.cn)
# Cold and Arid Regions Environmental and Engineering Research Institute, 
# or new institute name, the same institute to me, just changed a name 
# Northwest Institute of Eco-Environment and Resources,
# Chinese Academy of Sciences
# updated: 30/03/2021
#

################################################################################
# Computing thawing index (ti)
# if input air temperature variablename: Thawing degree-days of air (Celsius degree-days)
# if input ground temperature variablename: Thawing degree-days of ground surface (Celsius degree-days)
################################################################################
Thawing_index <- function(Year, TempName, data=QTP_ATM) {
  
  ti <- sapply(Year, function(Year) tryCatch({
    abs(tapply(data[TempName][data[TempName] > 0 & data$Year==Year], 
                     data$Year[data[TempName] > 0 & data$Year==Year], sum, na.rm=T))
  }, error = function ( e ) {ti <- NA}
  , warning = function ( e ) {ti <- NA}
  ), simplify=T)
  
  idx <- !(sapply(ti, length))
  ti[idx] <- NA
  ti <- unlist(ti)
  
  names(ti) <- Year
  return(ti)
}

################################################################################
# computing Freezing index (fi)
# if input air temperature variablename: Freezing degree-days of air (Celsius degree-days) 
# if input ground temperature variablename: Freezing degree-days of ground surface (Celsius degree-days)
################################################################################
Freezing_index <- function(Year, TempName, data=QTP_ATM) {
  
  fi <- sapply(Year, function(Year) tryCatch({
    abs(tapply(data[TempName][data[TempName] <= 0 & data$Year==Year], 
               data$Year[data[TempName] <= 0 & data$Year==Year], sum, na.rm=T))
  }, error = function ( e ) {fi <- NA}
    , warning = function ( e ) {fi <- NA}
  ), simplify=T)
  
  idx <- !(sapply(fi, length))
  fi[idx] <- NA
  fi <- unlist(fi)
  
  names(fi) <- Year
  return(fi)
}

################################################################################
# Computing Mean Annual Air Temperature (MAAT)
################################################################################
MAAT <- function(Year, TempName="Temperature", data=QTP_ATM) {
  
  maat <- sapply(Year, function(Year) tryCatch({
    (Thawing_index(Year=Year, TempName=TempName, data=data) - 
             Freezing_index(Year=Year, TempName=TempName, data=data))/365
  }, error = function ( e ) {maat <- NA}
    , warning = function ( e ) {maat <- NA}
  ), simplify=T)
  
  names(maat) <- Year
  return(maat)
}

# EOF