# Plot Meteorogical station observation data, MAAT and MAGST permafrost indices
#
# Author: Lihui Luo (E-mail: luolh@lzb.ac.cn)
# Cold and Arid Regions Environmental and Engineering Research Institute, 
# or new institute name, the same institute to me, just changed a name 
# Northwest Institute of Eco-Environment and Resources,
# Chinese Academy of Sciences
# updated: 30/03/2021
#

# load packages
library(ggplot2)

# Init
# clear the environment
rm(list=ls())

# set workdir
#setwd("/QTEC")

# Data directory
DataRoot  <- './Data'

# Figure directory
FigRoot  <- './Figure'

#########################################################################
# Run MAAT.R & MAGST.R R files 
#########################################################################
source('MAAT.R')
source('MAGST.R')

#########################################################################
# plot and then create a Tiff formate figure 
# method = 'loess'
# LOESS regression method, LOESS is non-parametric regression methods that combine multiple 
#    regression models in a k-nearest-neighbor-based meta-model. 
#########################################################################
# read csv file
xdt <- read.csv(file.path(DataRoot, 'XDTMS2014-2018_GT.csv'), header = TRUE)

tiff(file.path(FigRoot, 'XDT_2014_2018.tif'), width=3*600, height=3*600, res=300)
xdt <- ggplot(xdt, aes(x=as.Date(Date), y=Val, group=Var)) + 
  geom_line(col="grey") +
  #geom_smooth(method = 'loess', col="green", se=FALSE) + 
  xlab("") +
  ylab("") +
  scale_x_date(date_breaks = "1 year", date_labels = "%Y") +
  facet_wrap( ~ Var, scales="free", ncol=1) +
  theme_bw()

print(xdt) # The Tiff Figure is generated after using print function
dev.off() # This function closes the specified plot (by default the current device)

# read csv file
xdt_p <- read.csv(file.path(DataRoot,'XDTMS2014-2018_PREC.csv'), header = TRUE)

tiff(file.path(FigRoot, 'XDT_2014_2018_PREC.tif'), width=3*600, height=3*150, res=300)
xdt_p <- ggplot(xdt_p, aes(x=as.Date(Date), y=Val, group=Var)) + 
  geom_bar(stat="identity", position=position_dodge(), col="grey") +
  #geom_smooth(method = 'loess', col="green", se=FALSE) +
  xlab("") +
  ylab("") +
  scale_x_date(date_breaks = "1 year", date_labels = "%Y") +
  facet_wrap( ~ Var, scales="free", ncol=1) +
  theme_bw()

print(xdt_p)
dev.off()

# Read meteorological data of Golmud field station 
go <- read.csv(file.path(DataRoot,'Meteo_52818_Golmud_1955-2020.csv'), header = TRUE)

# Read meteorological data of Wudaoliang field station 
wu <- read.csv(file.path(DataRoot,'Meteo_52908_Wudaoliang_1956_2020.csv'), header = TRUE)

# Read meteorological data of Xidatan field station 
xd <- read.csv(file.path(DataRoot,'XDTMS2014-2018.csv'), header = TRUE)

#########################################################################
# Run function and output csv file for MAAT 
#########################################################################
# "Temperature" is the air temperature, you can use variable name of air temperature instead
write.csv(MAAT(1956:2020, TempName="Temperature", data=go), file.path(DataRoot,'MAAT_Golmud1956-2020.csv'))

write.csv(MAAT(1956:2020, TempName="Temperature", data=wu), file.path(DataRoot,'MAAT_Wudaoliang1956-2020.csv'))

write.csv(MAAT(2014:2018, TempName="Temperature", data=xd), file.path(DataRoot,'MAAT_Xidatan2014-2018.csv'))

#########################################################################
# Run function and output csv file for MAGST 
#########################################################################
# "Temperature" is the air temperature, you can use variable name of air temperature instead
# "GT_0_AVG" and "GT" is the ground surface temperature. Similarly, this variable can also be replaced by other ground temperature variables
write.csv(MAGST(1956:2020, AirTempName="Temperature", GroundTempName="GT_0_AVG", data=go), file.path(DataRoot,'MAGST_Golmud1956-2020.csv'))

write.csv(MAGST(1956:2020, AirTempName="Temperature", GroundTempName="GT_0_AVG", data=wu), file.path(DataRoot,'MAGST_Wudaoliang1956-2020.csv'))

write.csv(MAGST(2014:2018, AirTempName="Temperature", GroundTempName="GT", data=go), file.path(DataRoot,'MAGST_Xidatan2014-2018.csv'))

#########################################################################
# Plot MAAT & MAGST
#########################################################################
# Read csv file, where combined MAAT and MAGST simulation data of Golmud and Wudaoliang field stations 
mgw <- read.csv(file.path(DataRoot,'MAAT_MAGST_Golmud_Wudaoliang_1956-2020.csv'), header = TRUE)

# plot and then create a Tiff formate figure 
tiff(file.path(FigRoot, 'MAAT_MAGST_Golmud_Wudaoliang_1956-2020.tif'), width=3*600, height=3*400, res=300)
mg <- ggplot(mgw, aes(x=Year, y=Value, group=Site, color=Site)) + 
  geom_line() +
  geom_smooth(method = 'loess') +
  scale_x_continuous(breaks=seq(1955,2020,10)) +
  xlab("Year") +
  ylab("") +
  facet_wrap( ~ Index, scales="free_y", ncol = 2) +
  theme_bw() +
  theme(legend.position=c(0.3,0.5),
        legend.title=element_blank(),legend.background = element_rect(fill=alpha('white', 0)))

print(mg)
dev.off()


